[llvm-commits] CVS: llvm/include/llvm/CodeGen/LiveIntervalAnalysis.h

Evan Cheng evan.cheng at apple.com
Mon May 8 23:38:01 PDT 2006



Changes in directory llvm/include/llvm/CodeGen:

LiveIntervalAnalysis.h updated: 1.51 -> 1.52
---
Log message:

PR 770: http://llvm.cs.uiuc.edu/PR770  - permit coallescing of registers in subset register classes.


---
Diffs of the changes:  (+5 -3)

 LiveIntervalAnalysis.h |    8 +++++---
 1 files changed, 5 insertions(+), 3 deletions(-)


Index: llvm/include/llvm/CodeGen/LiveIntervalAnalysis.h
diff -u llvm/include/llvm/CodeGen/LiveIntervalAnalysis.h:1.51 llvm/include/llvm/CodeGen/LiveIntervalAnalysis.h:1.52
--- llvm/include/llvm/CodeGen/LiveIntervalAnalysis.h:1.51	Wed Feb 22 10:23:43 2006
+++ llvm/include/llvm/CodeGen/LiveIntervalAnalysis.h	Tue May  9 01:37:48 2006
@@ -167,9 +167,11 @@
                                    unsigned SrcReg, unsigned DestReg,
                                    bool isLiveIn = false);
 
-    /// Return true if the two specified registers belong to different
-    /// register classes.  The registers may be either phys or virt regs.
-    bool differingRegisterClasses(unsigned RegA, unsigned RegB) const;
+    /// Return true if the two specified registers belong to the same or
+    /// compatible register classes.  The registers may be either phys or
+    /// virt regs.
+    bool compatibleRegisterClasses(unsigned RegA, unsigned RegB,
+                                   bool &Swap) const;
 
     bool AdjustIfAllOverlappingRangesAreCopiesFrom(LiveInterval &IntA,
                                                    LiveInterval &IntB,






More information about the llvm-commits mailing list